# pfinance
Python financial mathematics library.

## Installation
### Using pip

- run `pip install pfinance`

### Building from source

- clone the repo
- run `python setup.py bdist_wheel`

## Publishing to PyPI

Package builds are automatically published to PyPI on each version bump. Version changes should follow standard [semantic versioning guidelines](https://semver.org/).

## TODO list
- add support for automated installation of required packages in a local virtual env
- use commit tagging for versioning
- content:
  - more functions

